==> compass-susy-plugin_1.0.8~dfsg.orig.tar.gz: v1.0.8~dfsg/docs/source/sites-using-susy.html.md <==
---
title: Sites using Susy
---

## Sites Using Susy

- [Integrating Design](http://hholz.com/) [[source](https://github.com/hilary/hilary.github.com)]
- [Ben Frain](http://benfrain.com/)
- [Leo Burnett](http://leoburnett.co.uk/)
- [Renault TV](http://renault.tv/)
- [Tiga Minimal WordPress Theme](http://wordpress.org/extend/themes/tiga) [[source](https://github.com/satrya/tiga/downloads)]
- [Mozilla MozTrap](https://moztrap.mozilla.org/) [[source](https://github.com/mozilla/moztrap "MozTrap source")]
- [Cassie Greer](http://www.cassiegreer.com)
- [HR &hearts; PE](http://www.hrlovespe.com/)
- [My job would be easier if...](http://www.myjobwouldbeeasierif.com/)
- [Volunteer Center Northumberland](https://volunteeringnorthumberland.org.uk/)
- [Rita Konig](http://ritakonig.com/)
- [Concordia discors](http://www.ffzg.unizg.hr/zbor/) [[source](https://github.com/silvenon/concordia-discors "discords source")]
- [Waldorf camp](http://waldorfcamp.net/) [[source](https://github.com/jimick/waldorfcamp "Waldorf source")]
- [Matthew Balaam](http://www.matthewbalaam.co.uk/)
- [Starrt](http://starrt.dk/)
- [Jeremy Peters](http://jeremypeters.co.uk/)
- [Avoid Payday Loans](http://avoidpaydayloans.com/)
- [Fake Images Please](http://fakeimg.pl/)
- [Viggle](http://www.viggle.com/)
- [Studio Daniel Libeskind](http://daniel-libeskind.com/)
- [Devtroit](http://devtroit.com/)
- [Patrick Marsceill](http://patrickmarsceill.com)

Have a site to add? [Let us know](http://twitter.com/compasssusy/) or [fork and add your site on GitHub](https://github.com/ericam/susy).

==> compass-susy-plugin_1.0.9~dfsg.orig.tar.gz: v1.0.9~dfsg/docs/source/sites-using-susy.html.md <==
---
title: Sites using Susy
---

## Sites Using Susy

- [Sass and Compass book](http://sassandcompass.com)
- [Square Directory](https://squareup.com/directory)
- [Slickbag](http://slickbag.se/)
- [Wedge Detroit](http://wedgedetroit.com/)
- [Triquanta Drupal Specialist](http://www.triquanta.nl/)
- [Barcelona Ruby Conference 2013](http://www.baruco.org/)
- [BarCamp Rochester](http://barcamproc.org/)
- [Integrating Design](http://hholz.com/) [[source](https://github.com/hilary/hilary.github.com)]
- [Ben Frain](http://benfrain.com/)
- [Leo Burnett](http://leoburnett.co.uk/)
- [Tiga Minimal WordPress Theme](http://wordpress.org/extend/themes/tiga) [[source](https://github.com/satrya/tiga/downloads)]
- [Mozilla MozTrap](https://moztrap.mozilla.org/) [[source](https://github.com/mozilla/moztrap "MozTrap source")]
- [Cassie Greer](http://www.cassiegreer.com)
- [Volunteer Center Northumberland](https://volunteeringnorthumberland.org.uk/)
- [Rita Konig](http://ritakonig.com/)
- [Concordia discors](http://www.ffzg.unizg.hr/zbor/) [[source](https://github.com/silvenon/concordia-discors "discords source")]
- [Matthew Balaam](http://www.matthewbalaam.co.uk/)
- [Starrt](http://starrt.dk/)
- [Jeremy Peters](http://jeremypeters.co.uk/)
- [Avoid Payday Loans](http://avoidpaydayloans.com/)
- [Fake Images Please](http://fakeimg.pl/)
- [Viggle](http://www.viggle.com/)
- [Studio Daniel Libeskind](http://daniel-libeskind.com/)
- [Devtroit](http://devtroit.com/)
- [Patrick Marsceill](http://patrickmarsceill.com)
- [The Italian](http://theitalian.com.au)
- [Zwoio](http://www.zwoio.de)

Have a site to add? [Let us know](http://twitter.com/compasssusy/) or [fork and add your site on GitHub](https://github.com/ericam/susy).

## Other Mentions

- [Agile Designers](http://www.agiledesigners.com/resources/coding-tools/susy)
- [CSSDB](http://cssdb.co/search?q=susy)

<!--
[Renault TV](http://renault.tv/)
[HR &hearts; PE](http://www.hrlovespe.com/)
[My job would be easier if...](http://www.myjobwouldbeeasierif.com/)
 -->
